==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/pt_PT.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Ficheiros de Círculos",
    "Select circles to filter by" : "Selecione círculos para filtrar por",
    "No circles found" : "Não foram encontrados círculos",
    "Please select circles to filter by" : "Por favor, selecione os círculos para filtrar por",
    "No files found for the selected circles" : "Não foram encontrados ficheiros para os círculos selecionados",
    "You created the circle {circle}" : "Criou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
    "You deleted {circle}" : "Eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You linked {group} to {circle}" : "Associou {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} foi associado de {circle} por {author}",
    "You unlinked {group} from {circle}" : "Desassociou {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} foi desassociado do {circle} por [author]",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Alterou o nível do grupo associado {group} no {circle} para %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} alterou o nível do grupo associado {group} no {circle} para %1$s",
    "You joined {circle}" : "Juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se a {circle}",
    "You left {circle}" : "Saiu de {circle}",
    "{member} left {circle}" : "{member} saiu de {circle}",
    "Shared to Circles" : "Partilhado com Círculos",
    "Personal" : "Pessoal",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s partilhou »%s« consigo.",
    "%s on %s" : "%s às %s",
    "Password to access »%1$s« shared to you by %2$s" : "Palavra passe para aceder »%1$s« partilhado por si %2$s",
    "Password to access »%s«" : "Palavra-chave de acesso »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte palavra-chave:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clicar no botão abaixo para o abrir.",
    "Open »%s«" : "Abrir »%s«",
    "Circle not found" : "Círculo não encontrado",
    "A circle with that name exists" : "Já existe um círculo com esse nome",
    "You cannot join this circle" : "Não pode juntar-se a este círculo",
    "This member is not a moderator" : "Este membro não é um moderador",
    "Insufficient privileges" : "Privilégios insuficientes",
    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
    "You are already a member of this circle" : "Já é um membro deste círculo",
    "You have been blocked from this circle" : "Foi bloqueado neste círculo",
    "The user is already a member of this circle" : "O utilizador já é membro deste círculo",
    "The user has already been invited into this circle" : "O utilizador já foi convidado para este círculo",
    "Accept" : "Aceitar",
    "now" : "agora",
    "This user does not exist" : "Este utilizador não existe",
    "Email format is not valid" : "O formato de e-mail não é válido",
    "This contact is not available" : "Este contacto não está disponível",
    "Could not find share" : "Não foi possível encontrar a partilha",
    "No files in here" : "Sem ficheiros aqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "Allow linking of groups" : "Permitir associação de grupos",
    "Groups can be linked to circles." : "Os grupos podem ser associados aos grupos.",
    "Are you sure you want to transfer your ownership?" : "Tem a certeza que deseja transferir a sua propriedade?",
    "This action is irreversible" : "Esta ação é irreversível",
    "Personal circle" : "Círculo pessoal",
    "Secret circle" : "Círculo secreto",
    "Closed circle" : "Círculo fechado",
    "Public circle" : "Círculo público",
    "Link Removed" : "Associação Removida",
    "Request dismissed" : "Pedido rejeitado",
    "Request sent" : "Pedido enviado",
    "Link requested" : "Associação solicitada",
    "Personal Circle" : "Círculo Pessoal",
    "Secret Circle" : "Círculo Secreto",
    "Closed Circle" : "Círculo Fechado",
    "Public Circle" : "Círculo Público",
    "Secret" : "Secreto",
    "Closed" : "Fechado",
    "Public" : "Público",
    "Not a member" : "Não é um membro",
    "Unknown" : "Desconhecido",
    "Invited" : "Convidado",
    "Requesting" : "A solicitar",
    "Blocked" : "Bloqueado",
    "Kicked" : "Expulso",
    "Please confirm" : "Por favor, confirme",
    "Are you sure you want to leave this circle?" : "Tem a certeza que deseja sair deste círculo?",
    "Are you sure you want to delete this circle?" : "Tem a certeza que deseja eliminar este círculo?",
    "Mail Address" : "Endereço de Correio",
    "Kick this member" : "Expulsar este membro",
    "Accept the request" : "Aceitar o pedido",
    "Dismiss the request" : "Rejeitar o pedido",
    "Unlink this group" : "Desassociar este grupo",
    "Remove this link" : "Remover esta associação",
    "Cancel the link request" : "Cancelar o pedido de associação",
    "Accept the link request" : "Aceitar o pedido de associação",
    "Reject the link request" : "Rejeitar o pedido de associação",
    "Cannot join this circle" : "Não pode juntar-se a este círculo",
    "no error message" : "sem mensagem de erro",
    "You have joined this circle" : "Juntou-se a este círculo",
    "You have requested to join this circle" : "Solicitou a adesão a este círculo",
    "You have left this circle" : "Saiu deste círculo",
    "Cannot leave this circle" : "Não pode sair deste círculo",
    "You have deleted this circle" : "Eliminou este círculo",
    "Cannot delete this circle" : "Não pode eliminar este círculo",
    " {type} '{name}' created" : " {type} '{name}' criado",
    " {type} '{name}' could not be created" : "não foi possível criar {type} '{name}'",
    "Group '{name}' updated" : "'{name}' de grupo atualizado",
    "A link to <b>{remote}</b> has been requested." : "Foi solicitado uma associação para <b>{remote}</b>.",
    "Local User" : "Utilizador Local",
    "Local Group" : "Grupo Local",
    "Settings saved." : "Definições guardadas.",
    "%s shared »%s« with '%s'." : "%s partilhou »%s« com '%s'.",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s partilhado »%2$s« contigo.\nJá deverá ter recebido um outro e-mail com uma hiperligação para o aceder.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s partilhou »%2$s« consigo. Já deverá ter recebido um outro e-mail com uma hiperligação para o aceder.",
    "Remote circle does not accept federated links" : "O círculo remoto não aceita associações federadas",
    "Trying to link a circle to itself" : "A tentar associar um círculo a si mesmo ",
    "This link exists already" : "Esta associação já existe",
    "Create a new circle" : "Criar um novo círculo",
    "Select a circle type" : "Selecionar um tipo de círculo",
    "Create a personal circle" : "Criar um círculo pessoal",
    "Create a public circle" : "Criar um círculo público",
    "Create a closed circle" : "Criar um círculo fechado",
    "Create a secret circle" : "Criar um círculo secreto",
    "Creation" : "Criação",
    "A personal circle is a list of users known only to the owner." : "Um círculo pessoal é uma lista de utilizadores conhecida apenas pelo proprietário.",
    "Personal circles" : "Círculos pessoais",
    "Public circles" : "Círculos públicos",
    "Closed circles" : "Círculos fechados",
    "Secret circles" : "Círculos secretos",
    "All circles" : "Todos os círculos",
    "Search circles" : "Pesquisar por círculos",
    "No filter" : "Sem filtro",
    "Settings" : "Definições",
    "Add a member" : "Adicionar um membro",
    "Link a group" : "Associar um grupo",
    "Link a circle" : "Associar um círculo",
    "Join this circle" : "Junte-se a este círculo",
    "Delete circle" : "Eliminar círculo",
    "Edit circle" : "Editar círculo",
    "Accept the invitation" : "Aceitar o convite",
    "Decline the invitation" : "Rejeitar o convite",
    "Leave this circle" : "Sair deste círculo",
    "Link to a circle" : "Associar a um círculo",
    "Return to menu" : "Voltar ao menu",
    "Username" : "Nome de utilizador",
    "Level" : "Nível",
    "Status" : "Estado",
    "Joined" : "Aderiu",
    "Group Name" : "Nome do Grupo",
    "Link" : "Associar",
    "Linked" : "Associado",
    "Description" : "Descrição",
    "Change password" : "Alterar palavra-passe",
    "Allow Federated Links" : "Permitir Associações Federadas",
    "Accept Link Request Automatically" : "Aceitar Automaticamente o Pedido de Associação",
    "Save settings" : "Guardar definições"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/pt_PT.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "Circles' files" : "Ficheiros de Círculos",
    "Select circles to filter by" : "Selecione círculos para filtrar por",
    "No circles found" : "Não foram encontrados círculos",
    "Please select circles to filter by" : "Por favor, selecione os círculos para filtrar por",
    "No files found for the selected circles" : "Não foram encontrados ficheiros para os círculos selecionados",
    "You created the circle {circle}" : "Criou o círculo {circle}",
    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
    "You deleted {circle}" : "Eliminou {circle}",
    "{author} deleted {circle}" : "{author} eliminou {circle}",
    "You linked {group} to {circle}" : "Associou {group} a {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} foi associado de {circle} por {author}",
    "You unlinked {group} from {circle}" : "Desassociou {group} de {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} foi desassociado do {circle} por [author]",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Alterou o nível do grupo associado {group} no {circle} para %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} alterou o nível do grupo associado {group} no {circle} para %1$s",
    "You joined {circle}" : "Juntou-se a {circle}",
    "{member} joined {circle}" : "{member} juntou-se a {circle}",
    "You left {circle}" : "Saiu de {circle}",
    "{member} left {circle}" : "{member} saiu de {circle}",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Visible" : "Visível",
    "Open" : "Abrir",
    "Hidden" : "Escondido",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federada",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "%s shared »%s« with you." : "%s partilhou »%s« consigo.",
    "%s on %s" : "%s às %s",
    "Password to access »%1$s« shared to you by %2$s" : "Palavra passe para aceder »%1$s« partilhado por si %2$s",
    "Password to access »%s«" : "Palavra-chave de acesso »%s«",
    "It is protected with the following password:" : "Está protegido com a seguinte palavra-chave:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Clicar no botão abaixo para o abrir.",
    "Open »%s«" : "Abrir »%s«",
    "Circle not found" : "Círculo não encontrado",
    "A circle with that name exists" : "Já existe um círculo com esse nome",
    "You cannot join this circle" : "Não pode juntar-se a este círculo",
    "This member is not a moderator" : "Este membro não é um moderador",
    "Insufficient privileges" : "Privilégios insuficientes",
    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
    "You are already a member of this circle" : "Já é um membro deste círculo",
    "You have been blocked from this circle" : "Foi bloqueado neste círculo",
    "Accept" : "Aceitar",
    "%s" : "%s",
    "Personal Circle" : "Círculo Pessoal",
    "now" : "agora",
    "Email format is not valid" : "O formato de e-mail não é válido",
    "This contact is not available" : "Este contacto não está disponível",
    "Could not find share" : "Não foi possível encontrar a partilha",
    "No files in here" : "Sem ficheiros aqui",
    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
    "Name" : "Nome",
    "Size" : "Tamanho",
    "Modified" : "Modificado",
    "The user is already a member of this circle" : "O utilizador já é membro deste círculo",
    "The user has already been invited into this circle" : "O utilizador já foi convidado para este círculo",
    "This user does not exist" : "Este utilizador não existe"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
